@@ -23,6 +23,7 @@ Basic types.
 
 import typing as tp
 
-AMQPBody: tp.TypeAlias = bytes | str
+AMQPScalar: tp.TypeAlias = str | bool | int | float
+AMQPBody: tp.TypeAlias = bytes | dict[AMQPScalar, AMQPScalar] | AMQPScalar
 
 # vim: sw=4:et:ai
